"""
  >>> grok.testing.grok(__name__)
  Traceback (most recent call last):
  ...
  ConfigurationExecutionError: martian.error.GrokError: Multiple possible ways to render view <class 'megrok.layout.tests.test_renderandtemplate.MyLayout'>. It has both a 'render' method as well as an associated template.
  in:
  <BLANKLINE>
"""

import grokcore.component as grok
from grokcore.view import View
from megrok.layout import Layout
from zope.interface import Interface


class MyLayout(Layout):
    grok.context(Interface)

    def render(self):
        return ""

def test_suite():
    from zope.testing import doctest
    from megrok.layout.ftests import FunctionalLayer
    suite = doctest.DocTestSuite(
        optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS
        )
    suite.layer = FunctionalLayer
    return suite



import unittest
import doctest
from zope.testing import cleanup
from zope.testing import module
import zope.component.eventtesting
from zope import component
from megrok import layout
from grokcore.component.testing import grok_component as default_grok_component


def grok_component(name, component, **kwargs):
    # Because of undocumented but ok change in grokcore.component,
    # grok_component doesn't work anymore in doctests.
    component.__grok_module__ = 'megrok.layout'
    return default_grok_component(name, component, **kwargs)


def moduleSetUp(test):
    module.setUp(test, '__main__')

def moduleTearDown(test):
    module.tearDown(test)
    cleanup.cleanUp()

def zopeSetUp(test):
    zope.component.eventtesting.setUp(test)

def zopeTearDown(test):
    cleanup.cleanUp()

def test_suite():
    optionflags = doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS
    globs = {'grok_component': grok_component}
    suite = unittest.TestSuite()

    suite.addTest(
        doctest.DocFileSuite(
            '../README.txt',
            optionflags=optionflags,
            setUp=moduleSetUp,
            tearDown=moduleTearDown,
            globs=globs)
        )

    return suite



# -*- coding: utf-8 -*-

from grokcore.view import interfaces
from zope.interface import Interface


class ILayout(Interface):
    """Layout code.
    """


class IPageAware(Interface):
    """A view which is able to use a layout to render itself.
    """

    def contents():
        """Return the content of the page to be included in the
        layout.
        """


class IPage(IPageAware, interfaces.IGrokView):
    """A template using a layout to render itself.
    """


class ICodePage(IPage):
    """A template using a layout to render itself.
    """

